import random
import pygame as pg
import pygame.image

from settings import *


class Player():
    def __init__(self, x, y,screen,pifu):
        self.screen = screen
        self.die_image=[]
        self.die=0#0表示活着 1表示在泡泡里 2表示死亡
        self.pifu=pifu
        """
        宝宝初始 泡泡个数 泡泡范围 1  1 完美是 5   7
        蓝蓝初始 泡泡个数 泡泡范围 2  1 完美是 7   5
        """
        self.image=None
        if self.pifu==1:
            self.die_image=[pygame.image.load("image/baobao/1.png"),pygame.image.load("image/baobao/1.png"),pygame.image.load("image/baobao/2.png"),pygame.image.load("image/baobao/3.png"),
                            pygame.image.load("image/baobao/2.png"),pygame.image.load("image/baobao/3.png"),pygame.image.load("image/baobao/2.png"),pygame.image.load("image/baobao/3.png"),
                            pygame.image.load("image/baobao/2.png"),pygame.image.load("image/baobao/3.png"),pygame.image.load("image/baobao/2.png"),pygame.image.load("image/baobao/3.png"),
                            pygame.image.load("image/baobao/2.png"), pygame.image.load("image/baobao/3.png"),pygame.image.load("image/baobao/2.png"), pygame.image.load("image/baobao/3.png"),
                            pygame.image.load("image/baobao/4.png"),pygame.image.load("image/baobao/5.png"),pygame.image.load("image/baobao/6.png"),pygame.image.load("image/baobao/8.png"),
                            None,pygame.image.load("image/baobao/7.png"),None,pygame.image.load("image/baobao/7.png"),None,pygame.image.load("image/baobao/7.png"),
                            None,pygame.image.load("image/baobao/7.png"),None,pygame.image.load("image/baobao/7.png"),None,pygame.image.load("image/baobao/7.png"),
                            None, pygame.image.load("image/baobao/7.png"), None, pygame.image.load("image/baobao/7.png"), None, pygame.image.load("image/baobao/7.png")]
            self.image = pg.image.load("image/player.png")
        elif self.pifu==2:
            self.die_image=[pygame.image.load("image/marid/1.png"),pygame.image.load("image/marid/1.png"),pygame.image.load("image/marid/2.png"),pygame.image.load("image/marid/3.png"),
                            pygame.image.load("image/marid/2.png"),pygame.image.load("image/marid/3.png"),pygame.image.load("image/marid/2.png"),pygame.image.load("image/marid/3.png"),
                            pygame.image.load("image/marid/2.png"),pygame.image.load("image/marid/3.png"),pygame.image.load("image/marid/2.png"),pygame.image.load("image/marid/3.png"),
                            pygame.image.load("image/marid/2.png"), pygame.image.load("image/marid/3.png"),pygame.image.load("image/marid/2.png"), pygame.image.load("image/marid/3.png"),
                            pygame.image.load("image/marid/4.png"),pygame.image.load("image/marid/5.png"),pygame.image.load("image/marid/6.png"),pygame.image.load("image/marid/8.png"),
                            None,pygame.image.load("image/marid/7.png"),None,pygame.image.load("image/marid/7.png"),None,pygame.image.load("image/marid/7.png"),
                            None,pygame.image.load("image/marid/7.png"),None,pygame.image.load("image/marid/7.png"),None,pygame.image.load("image/marid/7.png"),
                            None, pygame.image.load("image/marid/7.png"), None, pygame.image.load("image/marid/7.png"), None, pygame.image.load("image/marid/7.png")]
            self.image = pg.image.load("image/player3.png")
        #player 's outlook color etc
        #self.image.fill(YELLOW)
        self.rect = self.image.get_rect()
        self.x = x
        self.y = y
        self.hp = 2
        self.die_zhen=0
        self.shanshuo_zhen = 0
        self.cishu = 15
        self.time = 8
        self.fanwei = 5#炸弹范围
        self.shuliang = 1#炸弹数量
        self.pifu=pifu
        #17帧是被怪物和人撞到的效果
    # move the player function
    def move(self, dx=0, dy=0):
        self.x += dx
        self.y += dy
    def hurt(self):
        self.shanshuo_zhen = 1
    def update(self):
        self.rect.x = self.x * TILESIZE
        self.rect.y = self.y * TILESIZE
        if self.die<2:
            if self.die==0:
                if self.shanshuo_zhen == 1:
                    self.time -= 1
                    if self.time == 0:
                        self.cishu -= 1
                        self.time = 8
                        if self.cishu == 0:
                            self.shanshuo_zhen=0
                            self.cishu=15
                    if self.cishu % 2 == 1:
                        self.image.set_alpha(100)
                    else:
                        self.image.set_alpha(255)
                self.screen.blit(self.image, (self.rect.x,self.y * TILESIZE))
            elif self.die==1:
                if self.die_zhen+1==len(self.die_image):
                    self.die=2
                if self.time>=8:
                    self.die_zhen+=1
                    self.time=0
                self.time+=1
                if self.die_image[self.die_zhen] != None:
                    self.screen.blit(self.die_image[self.die_zhen], (self.rect.x,self.y * TILESIZE))
    def zuobiaox(self):
        return self.x
    def zuobiaoy(self):
        return self.y
class Wall():
    def __init__(self,screen, x, y,leixing):
        self.screen = screen
        if leixing=="stone":
            self.image = pygame.image.load("image/fangkuai/stone.png")
        elif leixing=="wall":
            self.image = pygame.image.load("image/fangkuai/wall.png")
        self.rect = self.image.get_rect()
        self.x = x
        self.y = y
        self.rect.x = x * TILESIZE
        self.rect.y = y * TILESIZE
    def update(self):
        self.screen.blit(self.image,(self.rect.x,self.rect.y))
class Play_imformation():
    def __init__(self,screen,js_leixing,name,xuhao):
        self.screen=screen
        self.zhuang_tai=0 #0为正常1为哭泣状态
        self.js=None
        self.js_die=None
        if js_leixing==1:
            self.js=pg.image.load("image/play_imformation/baobao_icon.png")
            self.js_die=pg.image.load("image/play_imformation/baobao_cry_icon.png")
        elif js_leixing==2:
            self.js=pg.image.load("image/play_imformation/lanlan_icon.png")
            self.js_die=pg.image.load("image/play_imformation/lanlan_cry_icon.png")
        self.dengji=pg.image.load("image/play_imformation/grade.png")
        self.my_font = pygame.font.SysFont('SimHei', 16)
        self.name=name
        self.name_message = self.my_font.render(self.name, True, (255,255,255), (12, 116, 208))
        self.xuhao=xuhao
    def update(self):
        if self.zhuang_tai==0:
            self.screen.blit(self.js,(1070,153+self.xuhao*64))
        else:
            self.screen.blit(self.js_die,(1070,153+self.xuhao*64))
        self.screen.blit(self.dengji,(1141,155+self.xuhao*64))
        self.screen.blit(self.name_message,(1138,181+self.xuhao*64))
class player_icons():
    def __init__(self,screen,pifu,name,xh,zhunbei):
        self.name=name
        self.my_font = pygame.font.SysFont('SimHei', 16)
        self.name_message = self.my_font.render(self.name, True, (255,255,255))
        self.ready_img=pygame.image.load("BNB/准备.png")
        self.ready=False
        if zhunbei=="ready":self.ready=True
        self.screen=screen
        self.xuhao=xh#表示位置
        if pifu==1:
            self.hero_icon=pygame.image.load("BNB/baobao.png")
        else:
            self.hero_icon=pygame.image.load("BNB/lanlan.png")
        self.rect = self.hero_icon.get_rect()
        self.rect.x = 45 + 159 * xh + 6
        self.rect.y = 280 + 220 * (self.xuhao //4) - self.rect.height
    def update(self):
        #名字和角色都渲染
        self.screen.blit(self.hero_icon,(self.rect.x,self.rect.y))
        self.screen.blit(self.name_message,(52+160*self.xuhao,300+220*(self.xuhao //4)))
        #74 327
        if self.ready:self.screen.blit(self.ready_img,(43+160*self.xuhao,323+220*(self.xuhao //4)))
class Box():
    def __init__(self, screen, x, y,xuhao,leixing):
        self.screen=screen
        self.xuhao=xuhao
        if leixing=="box":
            self.image = pg.image.load("image/fangkuai/box.png")
        elif leixing=="orange_box":
            self.image=pg.image.load("image/fangkuai/orange_box.png")
        elif leixing=="red_box":
            self.image=pg.image.load("image/fangkuai/red_box.png")
        self.die_image=[pg.image.load("image/box_Explosive effect/Explosive effect1.png"),pg.image.load("image/box_Explosive effect/Explosive effect2.png"),
                        pg.image.load("image/box_Explosive effect/Explosive effect3.png"),pg.image.load("image/box_Explosive effect/Explosive effect4.png"),
                        None,pg.image.load("image/box_Explosive effect/Explosive effect4.png"),None,pg.image.load("image/box_Explosive effect/Explosive effect4.png")]
        self.die_zhen=0
        self.time=0
        self.x = x
        self.y = y
        self.die=0# 0为正常 1为被水泡炸到后的效果 2为效果结束[删除]
        self.daoju=random.randint(1,6)
    def update(self):
        if self.die==0:
            self.screen.blit(self.image,(self.x*33,self.y*33))
        if self.die==1:
            if self.die_zhen + 1 == len(self.die_image):
                self.die = 2
            if self.time >= 8:
                self.die_zhen += 1
                self.time = 0
            self.time += 1
            if self.die_image[self.die_zhen] != None:
                self.screen.blit(self.die_image[self.die_zhen], (self.x*33,self.y*33))
class Bomb():
    def __init__(self,x,y,screen,ditu,fanwei,msg,index):
        self.ditu=ditu
        self.index=index
        self.screen=screen
        self.msg=msg
        self.bomb_image=[]
        self.baozha_image=[]
        a = random.randint(0, 3)
        if a==0:
            for i in range(1,5):
                self.bomb_image.append(pg.image.load("image/bomb/bomb"+str(i)+".png"))
        elif a==1:
            for i in range(1,5):
                self.bomb_image.append(pg.image.load("image/bomb/mqj_bomb"+str(i)+".png"))
        elif a==2:
            for i in range(1,5):
                self.bomb_image.append(pg.image.load("image/bomb/dimo_bomb"+str(i)+".png"))
        else:
            for i in range(1,5):
                self.bomb_image.append(pg.image.load("image/bomb/milk_bomb"+str(i)+".png"))
        for i in range(1,5):
            self.baozha_image.append(pg.image.load("image/xiaoguo-"+str(i)+".png"))
        self.donghua_time=0
        self.zhen=0#泡泡动画帧数
        self.time=250#爆炸time
        self.x=x
        self.y=y
        self.fanwei=fanwei#泡泡范围
        self.left=-self.fanwei
        self.right=self.fanwei+1
        self.top=-self.fanwei
        self.down=self.fanwei+1
        self.baozha_list=[]
        self.Indestructible_Cube="12456789"# 不可被炸方块 3是表示爆炸
        self.Explosive_Cube="abcdcfg"# 可被炸方块
        #self.baozha_list=[]
        #32x32
    def list(self):
        return self.baozha_list
    def update(self):
        #4边检查箱子就不要-1
        self.time-=1
        if self.time==60:
            for i in range(-1,-1*self.fanwei-1,-1):
                if self.ditu[self.y][self.x+i] in self.Indestructible_Cube:
                    self.left = i+1
                    break
                elif self.ditu[self.y][self.x+i] in self.Explosive_Cube:
                    self.left= i+1
                    self.baozha_list.append([self.x+i,self.y])
                    break
            for i in range(0,1*self.fanwei+1):
                if self.ditu[self.y][self.x+i] in self.Indestructible_Cube :
                    self.right = i
                    break
                elif self.ditu[self.y][self.x+i] in self.Explosive_Cube:
                    self.right= i
                    self.baozha_list.append([self.x+i,self.y])
                    break
            for i in range(-1,-1*self.fanwei-1,-1):
                if self.ditu[self.y+i][self.x] in self.Indestructible_Cube:
                    self.top = i+1
                    break
                elif self.ditu[self.y+i][self.x] in self.Explosive_Cube:
                    self.top= i+1
                    self.baozha_list.append([self.x,self.y+i])
                    break
            for i in range(0,1*self.fanwei+1):
                if self.ditu[self.y+i][self.x] in self.Indestructible_Cube :
                    self.down = i
                    break
                elif self.ditu[self.y+i][self.x] in self.Explosive_Cube:
                    self.down= i
                    self.baozha_list.append([self.x,self.y+i])
                    break
            for i in range(self.top,self.down):
                self.ditu[self.y+i]=self.ditu[self.y+i][:self.x]+"3"+self.ditu[self.y+i][self.x+1:]
            for i in range(self.left,self.right):
                if i!=0:
                    self.ditu[self.y]=self.ditu[self.y][:self.x+i]+"3"+self.ditu[self.y][self.x+i+1:]
        elif self.time==0:
            for i in range(self.top,self.down):
                if self.ditu[self.y+i][self.x]=="3":
                    self.ditu[self.y+i]=self.ditu[self.y+i][:self.x]+"."+self.ditu[self.y+i][self.x+1:]
            for i in range(self.left,self.right):
                if i!=0:
                    self.ditu[self.y]=self.ditu[self.y][:self.x+i]+"."+self.ditu[self.y][self.x+i+1:]
        elif 0<self.time<=60:
            for i in range(self.top,self.down):
                if self.ditu[self.y+i][self.x]!="3":
                    self.ditu[self.y+i]=self.ditu[self.y+i][:self.x]+"3"+self.ditu[self.y+i][self.x+1:]
            for i in range(self.left,self.right):
                if i!=0:
                    self.ditu[self.y]=self.ditu[self.y][:self.x+i]+"3"+self.ditu[self.y][self.x+i+1:]
            for i in range(self.top, self.down):
                if i <=0:
                    self.screen.blit(self.baozha_image[1], ((self.x) * 33, (self.y + i) * 33))
                else:
                    self.screen.blit(self.baozha_image[3], ((self.x) * 33, (self.y + i) * 33))
            for i in range(self.left, self.right):
                if i<0:
                    self.screen.blit(self.baozha_image[0], ((self.x + i) * 33, self.y * 33))
                else:
                    self.screen.blit(self.baozha_image[2], ((self.x + i) * 33, self.y * 33))
        else:
            self.donghua_time+=1
            if self.donghua_time==15:
                self.zhen+=1
                self.donghua_time=0
            if self.zhen>3:
                self.zhen=0
            self.screen.blit(self.bomb_image[self.zhen],(self.x*33,self.y*33))


class Robot():
    def __init__(self,screen,ditu,zt):#人机自带x,y不需要
        self.screen=screen
        self.ditu=ditu
        self.zt=zt#状态的话 1是 动的 2 是通过传输信息给人机位置
        self.y=random.randint(1,len(self.ditu)-1)
        self.image=pg.image.load("image/monster.png")
        self.image1=pg.image.load("image/monster1.png")
        self.hp=2#代表血量
        self.fx=0#表示方向
        self.time=100
        self.shanshuo_zhen = 0
        self.cishu = 15
        self.time1 = 8
        self.fanwei=2
        self.shuliang=1
        while True:
            self.x=random.randint(1,len(self.ditu)-1)
            if self.ditu[self.y][self.x] == ".":
                break
    def move(self,ditu):
        if self.zt !=2:
            self.time-=1
            if self.time==0:
                self.time=random.randint(50,120)
                self.fx=random.randint(1,4)
            if self.fx>0:
                self.ditu=ditu
                if self.fx==1:
                    if self.ditu[self.y][self.x-1]==".":
                        self.x-=1
                elif self.fx==2:
                    if self.ditu[self.y-1][self.x] == ".":
                        self.y -= 1
                elif self.fx==3:
                    if self.ditu[self.y][self.x+1] == ".":
                        self.x += 1
                elif self.fx==4:
                    if self.ditu[self.y+1][self.x] == ".":
                        self.y += 1
                self.fx=0
    def suiji(self):
        return random.randint(1,10)
    def fangzhi_zhadan(self):
        if self.zt!=2:
            a=random.randint(1,1000)
            if a == 1:
                return True
    def hurt(self):
        self.shanshuo_zhen=1
        self.hp-=1
    def update(self,ditu):
        self.move(ditu)
        if self.shanshuo_zhen == 1:
            self.time1 -= 1
            if self.time1 == 0:
                self.cishu -= 1
                self.time1 = 8
                if self.cishu == 0:
                    self.shanshuo_zhen=0
                    self.cishu=15
            if self.cishu % 2 == 1:
                self.screen.blit(self.image,(self.x*32,self.y*32))
            else:
                self.screen.blit(self.image1,(self.x*32,self.y*32))
        else:
            self.screen.blit(self.image, (self.x*32, self.y*32))
class Daoju():
    def __init__(self,screen,x,y,id,index):
        self.image=pg.image.load("image/道具.png")
        self.image1=pg.image.load("image/yaoshui.png")
        self.screen=screen
        self.index=index
        self.x=x
        self.y=y
        self.pianyi=0#y轴移动
        self.bianliang=0.15
        self.daoju=None
        self.id=id
        if self.id==1:#1为炸弹数量
            self.daoju=self.image
        elif self.id==2:#2为炸弹范围
            self.daoju=self.image1
    def update(self):
        if self.pianyi<=-15 or self.pianyi>=0:
            self.bianliang=-self.bianliang
        self.pianyi+=self.bianliang
        self.screen.blit(self.daoju,(self.x*33,self.y*33+self.pianyi))
    @staticmethod
    def jiance(id):
        if id<=2:
            return True
        else:
            return False

class chat_box():
    def __init__(self,screen,duixiang,sever,sf):
        self.sf=sf
        self.screen=screen#当前窗口
        self.sever=sever#绑定服务器实现指令传输
        self.duixiang=duixiang#游戏类
        self.ground=pg.image.load("image/black.png")
        self.chat_list=[]#记录信息update便利渲染
        self.name=self.duixiang.name #记录的是自己的游戏名字
        self.useing=False
        self.current_content=""
        self.content_update=None
        #初始化字体类型
        self.my_font = pygame.font.SysFont('SimHei', 35)
        self.time=100
    def update(self):
        if self.useing:
            self.screen.blit(self.ground,(0,718))
            self.screen.blit(self.content_update,(0,718))
        if len(self.chat_list)>0:
            for index,i in enumerate(self.chat_list):
                self.screen.blit(i,(10,index*35+500))
            self.time-=1
            if self.time==0:
                self.time=100
                del self.chat_list[0]
    def event(self,event_val):
        if event_val==13:
            if self.useing:
                if len(self.current_content)>0:
                    #根据指令信息判断
                    if self.sf=="sever":
                        if len(self.chat_list) < 6:
                            self.chat_list.append(
                                self.my_font.render(self.name + ":" + self.current_content, True, (0,0,139)))
                        else:
                            del self.chat_list[0]
                            self.chat_list.append(self.my_font.render(self.name + ":" + self.current_content, True, (0,0,139)))
                        self.sever.send_player("2|chat|" + self.name + ":" + self.current_content)
                    else:
                        self.sever.sendall(("2|chat|" + self.name + ":" + self.current_content).encode("utf8"))
                    self.current_content=""
                    self.time=100
                else:
                    self.useing=False
                    self.current_content=""
            else:
                self.useing=True
                self.current_content = ""
        if self.useing:
            if len(self.current_content)>0:
                if event_val==8:self.current_content=self.current_content[:-1]
            if 97<=event_val<=122:
                self.current_content+=chr(event_val)
            elif 1073741913<=event_val<=1073741922:
                self.current_content+=chr((48+event_val-1073741913))
            elif event_val==32:
                self.current_content+=" "
            self.content_update=self.my_font.render(self.current_content, True, (255, 255, 255), (12, 116, 208))
    def add_information(self,msg):
        if len(self.chat_list) < 6:
            self.chat_list.append(self.my_font.render(msg, True, (0,0,139)))
        else:
            del self.chat_list[0]
            self.chat_list.append(self.my_font.render(msg, True, (0,0,139)))
        self.time=100
class ghost():
    def __init__(self,screen,map):
        self.screen=screen
        self.map=map
        self.y=random.randint(1,len(self.map)-2)
        self.x=None
        while True:
            shu=random.randint(0,len(self.map[self.y])-1)
            if self.map[self.y][shu]==".":
                self.x=shu
                break
        self.born=False
        self.born_image=[]
        self.left_image=[]
        self.right_image=[]
        self.top_image=[]
        self.down_image=[]
        self.die_image=[]
        self.time=30
        self.zhen=0
        self.fx=0
        self.jineng_time=10#冲刺时间倒计时
        self.use_jineng=False
        self.chongci_donghua=False
        self.die=0
        for i in range(1,5):
            if i<=3:
                self.born_image.append(pg.image.load("image/ghost/youling_xiaoguo"+str(i)+".png"))
            self.left_image.append(pg.image.load("image/ghost/youling_zuo"+str(i)+".png"))
            self.right_image.append(pg.image.load("image/ghost/youling_you"+str(i)+".png"))
            self.top_image.append(pg.image.load("image/ghost/youling_shang"+str(i)+".png"))
            self.down_image.append(pg.image.load("image/ghost/youling_xia"+str(i)+".png"))
        self.use_image=self.down_image[0]#默认为正面
        for i in range(3,0,-1):
            self.die_image.append(pg.image.load("image/ghost/youling_xiaoguo"+str(i)+".png"))
    def update(self):
        if self.die==1:
            self.time -= 1
            self.screen.blit(self.die_image[self.zhen], (self.x * 33, self.y * 33))
            if self.time == 0:
                self.zhen += 1
                self.time = 12
            if self.zhen == 3:
                self.die=2
        else:
            if not self.born:
                self.time-=1
                self.screen.blit(self.born_image[self.zhen],(self.x*33,self.y*33))
                if self.time==0:
                    self.zhen+=1
                    self.time=12
                if self.zhen==3:
                    self.born=True
            else:
                if self.map[self.y][self.x]=="3":
                    self.zhen=0
                    self.die=1
                if self.use_jineng:
                    self.chongci()
                else:
                    if self.time==0:
                        self.time=30
                        while True:
                            shu=random.randint(0,3)
                            if shu==0:
                                if self.map[self.y][self.x-1]==".":
                                    self.x-=1
                                    self.use_image=self.left_image[0]
                            elif shu==1:
                                if self.map[self.y-1][self.x]==".":
                                    self.y-=1
                                    self.use_image=self.top_image[0]
                            elif shu==2:
                                if self.map[self.y][self.x+1]==".":
                                    self.x+=1
                                    self.use_image=self.right_image[0]
                            elif shu==3:
                                if self.map[self.y+1][self.x]==".":
                                    self.y+=1
                                    self.use_image=self.down_image[0]
                            break
                    if self.jineng_time==0:
                        self.zhen=0
                        self.jineng_time=300
                        self.chongci_donghua=False
                        self.use_jineng=True
                        self.fx=random.randint(0,3)
                    self.jineng_time-=1
                    self.screen.blit(self.use_image,(self.x*33,self.y*33))
                    self.time -= 1
    def chongci(self):
        if not self.chongci_donghua:
            self.time -= 1
            if self.fx==0:
                self.use_image=self.left_image[self.zhen]
            elif self.fx==1:
                self.use_image=self.top_image[self.zhen]
            elif self.fx==2:
                self.use_image=self.right_image[self.zhen]
            elif self.fx==3:
                self.use_image=self.down_image[self.zhen]
            if self.time == 0:
                self.time=15
                self.zhen += 1
            if self.zhen == 4:
                self.chongci_donghua = True
        else:
            if self.time==0:
                self.time=4
                if self.fx==0:
                    if self.map[self.y][self.x-1]==".":
                        self.x-=1
                    else:
                        self.use_jineng=False
                        self.zhen=0
                elif self.fx==1:
                    if self.map[self.y-1][self.x]==".":
                        self.y-=1
                    else:
                        self.use_jineng=False
                        self.zhen=0
                elif self.fx==2:
                    if self.map[self.y][self.x+1]==".":
                        self.x+=1
                    else:
                        self.use_jineng=False
                        self.zhen=0
                elif self.fx==3:
                    if self.map[self.y+1][self.x]==".":
                        self.y+=1
                    else:
                        self.use_jineng=False
                        self.zhen=0
            self.time-=1
        self.screen.blit(self.use_image, (self.x * 33, self.y * 33))
class end_kuang():
    def __init__(self,screen,people_list,xuhao,me_xuhao):
        self.people_list = people_list
        self.screen = screen
        if xuhao==None:
            self.win= False
        else:
            if xuhao==me_xuhao:
                self.win = True
            else:
                self.win= False# this is win player id
        self.win_index=xuhao
        self.x = 150
        self.y = 120
        #按顺序为 结束框 胜利 min胜利 失败 min失败
        self.End_Interface=pg.image.load("image/end/End Interface.png")
        self.victory=pg.image.load("image/end/victory.png")
        self.small_vicroty=pg.image.load("image/end/small_victory.png")
        self.defeat=pg.image.load("image/end/defeat.png")
        self.small_defeat=pg.image.load("image/end/small_defeat.png")
        self.grade=pg.image.load("image/end/grade.png")
        self.blue=pg.image.load("image/end/blue_tiao.png")
        self.end_list=[]
        for i in range(1,9):
            self.end_list.append(pg.image.load("image/end/"+str(i)+".png"))
        self.my_font = pygame.font.SysFont('SimHei', 16)
        self.name=""
    def update(self):
        self.screen.blit(self.End_Interface,(self.x,self.y))
        index=0
        i=0
        if self.win:
            self.screen.blit(self.victory,(self.x+220,20))
        else:
            self.screen.blit(self.defeat,(self.x+220,20))
        for index,i in enumerate(self.people_list):
            if i!=None:
                self.screen.blit(self.end_list[index],(self.x+32,self.y+63+index*30+3))
                self.name = self.people_list[index].name
                self.name_message = self.my_font.render(self.name, True, (255, 255, 255))
                if self.win_index==index:
                    self.screen.blit(self.small_vicroty,(self.x+59,self.y+63+index*30+1))
                else:
                    self.screen.blit(self.small_defeat,(self.x+59,self.y+63+index*30+1))
                self.screen.blit(self.grade,(self.x+171,self.y+63+index*30+6))
                self.screen.blit(self.name_message,(self.x+195,self.y+63+index*30+6))



import pygame as pg
import time as shijian
import random
import sys
from os import path
from settings import *
from object import *
import socket
import threading as xianchen
class Game:
    def __init__(self):
        # initalize game window, etc...
        pg.init()
        '''
        pg.mixer.init()
        self.music=pg.mixer.music.load("image/1.mp3")
        self.music=pg.mixer.music.load("image/2.mp3")
        '''
        self.screen = pg.display.set_mode((800,600))
        pg.display.set_caption(TITLE)
        self.clock = pg.time.Clock()
        # Let the key press down
        pg.key.set_repeat(500, 100)
        #main界面
        self.mian_jiemian=pg.image.load("image/mainground.png")
        self.chuangjian_fj1=pg.image.load("BNB/xz1.png")
        self.chuangjian_fj2=pg.image.load("BNB/xz2.png")
        self.room=pg.image.load("BNB/room.png")
        self.black=pg.image.load("BNB/black.png")
        #
        #创建房间初始化(你是房主)
        self.sever=None
        self.client=None
        self.msg=""
        self.lianjie=False
        self.box_msg=""
        self.change_xinxi=False
        #房间数据
        self.thread=None
        self.player_msg_list=[]
        #开始游戏()
        self.player_play_list=[]
        #游戏人物信息框
        self.play_imformation_list=[]
        self.play_imformation_kuang=pg.image.load("image/play_imformation/play information box.png")
        #重要的数据包
        # 1是移动 2是放置炸弹 3是人机位置 4是怪物炸弹 5是刷新道具 6是拾取道具 7是墙的摧毁
        #用这种方式可以取消使用人物拾取道具的动作
        self.bomb_sjb="2|"#炸弹[数据包]
        self.daoju_sjb = "5|"  # 道具[数据包]
        self.robot_sjb = "3|"  # 机器人[数据包]
        self.robot_bomb_sjb = "4|"  # 机器人炸弹[数据包]
        self.box_sjb = "7|"  # 箱子[数据包]
        #
        self.zhen=255
        self.wall_list=[]
        self.daoju_list=[]# 道具
        self.robot_list=[]# 机器人
        self.robot_bomb=[]# 机器人炸弹
        self.box_list=[]# 箱子
        self.load_data()
        self.running = True
        self.bomb=[]#玩家炸弹
        self.cunfang=""
        self.bomb_shuliang=0
        self.jiemian=0
        #玩家皮肤信息
        self.player_index=0
        self.name=""
        self.x=0
        self.jishu=0
        self.choice_name()
        #32x24
        #pg.mixer.music.play(-1)
        """
        if pygame.mixer.music.get_busy() == False: #检查是否正在播放音乐
            pygame.mixer.music.play() #开始播放音乐流
        """
    def choice_name(self):
        self.name=random.choice(["Clever ","Naughty ","Handsome "," violent ","rich ","low-key ","steady ","Jovial"])+random.choice(["Duck","pig","froggy","John Doe","Passerby B","Bystander C","Xiao Ming","Xiao Hong","Xiao Zhang","Xiao Pao"])
    def receive(self):
            self.server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            self.server.bind((socket.gethostbyname(socket.gethostname()), 2001))
            self.server.listen(5)
            self.client, ip = self.server.accept()
            self.lianjie=True
            while True:
                try:
                    msg = self.client.recv(1024).decode("utf-8")

                    if msg.split("|")[0] == "1":
                        print(msg)
                        self.player_play1.x = int(msg.split("|")[1].split(",")[0])
                        self.player_play1.y = int(msg.split("|")[1].split(",")[1])
                    elif msg.split("|")[0] == "2":
                        #-1的话是因为后面会有多出一个*
                        #如果炸弹的x,y对不上该坐标将炸弹reomove掉,因为新加的炸弹在后面添加所以不会影响之前的炸弹的序号
                        if len(msg.split("|")[1].split("*"))-1!=self.robot_bomb:
                            self.map_data[int(msg.split("|")[1].split(",")[1])] = self.map_data[int(msg.split("|")[1].split(",")[1])][:int(msg.split("|")[1].split(",")[0])] + "3" + self.map_data[int(msg.split("|")[1].split(",")[1])][int(msg.split("|")[1].split(",")[0]) + 1:]
                            self.bomb.append(Bomb(int(msg.split("|")[1].split(",")[0]), int(msg.split("|")[1].split(",")[1]), self.screen, self.map_data, int(msg.split("|")[1].split(",")[2]), "123"))
                    elif msg.split("|")[0]== "3":
                        for i in range(0,len(msg.split("|")[1].split("."))):
                            self.robot_list[i].x=int(msg.split("|")[1].split(".")[i].split(",")[0])
                            self.robot_list[i].y=int(msg.split("|")[1].split(".")[i].split(",")[1])
                    elif msg.split("|")[0]=="4":
                        self.map_data[int(msg.split("|")[1].split(",")[1])] = self.map_data[int(msg.split("|")[1].split(",")[1])][:int(msg.split("|")[1].split(",")[0])] + "3" + self.map_data[int(msg.split("|")[1].split(",")[1])][int(msg.split("|")[1].split(",")[0]) + 1:]
                        self.robot_bomb.append(Bomb(int(msg.split("|")[1].split(",")[0]), int(msg.split("|")[1].split(",")[1]), self.screen, self.map_data, int(msg.split("|")[1].split(",")[2]), "guaishou"))
                        print("ok")
                    elif msg.split("|")[0]=="5":
                        self.daoju_list.append(Daoju(self.screen,int(msg.split("|")[1].split(",")[0]),int(msg.split("|")[1].split(",")[1]),int(msg.split("|")[1].split(",")[2])))
                    elif msg.split("|")[0]=="6":
                        del self.daoju_list[int(msg.split("|")[1])]
                    #1是移动 2是放置炸弹 3是人机位置 4是怪物炸弹 5是刷新道具 6是拾取道具 7是墙的摧毁
                    elif msg.split("|")[0]=="7":
                        del self.box_list[int(msg.split("|")[1])]
                except:
                    pass
    def connect(self):
        self.client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.client.connect(("192.168.1.103", 5000))
        self.client.sendall((("1|init|"+str(2)+","+self.name+",no ready")+".").encode("utf8"))
        while True:
            try:
                msg = self.client.recv(1024).decode("utf-8")
                print(msg)
                if msg.split("|")[0] == "1":#房间中的，，，
                    if msg.split("|")[1]=="Enter game":
                        self.jiemian=4
                    if msg.split("|")[1]=="msg":
                        self.change_xinxi=True
                        self.player_msg_list = []
                        for i in range(0, len(msg.split("|")[2].split(".")) - 1):
                            if msg.split("|")[2].split(".")[i] != "-1,no name,no ready":
                                self.player_msg_list.append(player_icons(self.screen, int(msg.split("|")[2].split(".")[i].split(",")[0]),msg.split("|")[2].split(".")[i].split(",")[1], i,msg.split("|")[2].split(".")[i].split(",")[2]))
                        self.change_xinxi=False
                elif msg.split("|")[0] == "2":#游戏中的....
                    # 表示角色初始化的数据
                    # split 不搞复杂 先| 在 . 在  ,取出你要的值
                    if msg.split("|")[1] == "js":
                        print(msg)
                        #                        x y   皮肤值   初始泡泡范围    名字
                        #用名字给出自己的游戏对象
                        if self.player_index==0:
                            for i in range(0,len(msg.split("|")[2].split(".")) - 1):
                                if msg.split("|")[2].split(".")[i].split(",")[4] == self.name:self.player_index = i
                                self.player_play_list.append(Player(int(msg.split("|")[2].split(".")[i].split(",")[0]),int(msg.split("|")[2].split(".")[i].split(",")[1]),self.screen,int(msg.split("|")[2].split(".")[i].split(",")[2])))
                                self.play_imformation_list.append(Play_imformation(self.screen,int(msg.split("|")[2].split(".")[i].split(",")[2]),msg.split("|")[2].split(".")[i].split(",")[4],int(msg.split("|")[2].split(".")[i].split(",")[5])))
                        else:
                            for i in range(0,len(msg.split("|")[2].split(".")) - 1):
                                if msg.split("|")[2].split(".")[i] == "None":
                                    if self.player_play_list[i] != None:
                                        print("ok")
                                        self.player_play_list[i] = None
                                        self.play_imformation_list[i] = None
                    elif msg.split("|")[1] == "end":
                        self.end_kuang=end_kuang(self.screen,self.play_imformation_list,int(msg.split("|")[2]),self.player_index)
                        self.shu_ying=True
                    elif msg.split("|")[1] == "chat":
                        self.chat_box.add_information(msg.split("|")[2])
                    elif msg.split("|")[1] == "property":
                        zhen=0
                        index=0
                        add=False
                        while True:
                            if index==len(self.daoju_list):
                                add=True
                                break
                            if index==len(msg.split("|")[2].split("."))-1:
                                i=0
                                while i<len(self.daoju_list):
                                    if self.daoju_list[i].index>=self.daoju_list[index].index:
                                        del self.daoju_list[i]
                                        i-=1
                                    i+=1
                            if self.daoju_list[index].index!=int(msg.split("|")[2].split(".")[index].split(",")[3]):
                                del self.daoju_list[index]
                            else:
                                index+=1
                                zhen+=1
                        if add:
                            for i in range(index,len(msg.split("|")[2].split("."))):
                                self.daoju_list.append(Daoju(self.screen,int(msg.split("|")[2].split(".")[i].split(",")[0]),int(msg.split("|")[2].split(".")[i].split(",")[1]),int(msg.split("|")[2].split(".")[i].split(",")[2]),int(msg.split("|")[2].split(".")[i].split(",")[3])))
                    elif msg.split("|")[1] == "life":
                        for index in range(0,len(msg.split("|")[2].split("."))-1):
                            if len(msg.split("|")[2].split("."))!="None":
                                if int(msg.split("|")[2].split(".")[index]) != self.player_play_list[index].die:
                                    self.player_play_list[index].die = int(msg.split("|")[2].split(".")[index])
                                    self.play_imformation_list[index].zhuang_tai=int(msg.split("|")[2].split(".")[index])
                    elif msg.split("|")[1] == "move":
                        for i in range(0,len(msg.split("|")[2].split(".")) - 1):
                            if msg.split("|")[2].split(".")[i]!="None":
                                self.player_play_list[i].x = int(msg.split("|")[2].split(".")[i].split(",")[0])
                                self.player_play_list[i].y = int(msg.split("|")[2].split(".")[i].split(",")[1])
                    elif msg.split("|")[1]=="box_xinxi":
                        for i in range(0,len(msg.split("|")[2].split(".")) - 1):
                            self.box_list[int(msg.split("|")[2].split(".")[i])].die=1
                    elif msg.split("|")[1] == "box":
                        for i in range(0,len(msg.split("|")[2].split("."))-1):
                            if self.box_list[i]!="No" and msg.split("|")[2].split(".")[i]=="No":
                                self.map_data[self.box_list[i].y]=self.map_data[self.box_list[i].y][:self.box_list[i].x]+"."+self.map_data[self.box_list[i].y][self.box_list[i].x+1:]
                                self.box_list[i]="No"
                    elif msg.split("|")[1]=="bomb":
                        #帧数不能从0开始
                        msg_index = 0
                        zhen = 0
                        if msg.split("|")[2]=="":
                            self.bomb=[]
                        else:
                            while True:
                                if zhen+1>len(self.bomb):
                                    break
                                if self.bomb[zhen].index!=int(msg.split("|")[2].split(".")[msg_index].split(",")[0]):
                                    del self.bomb[zhen]
                                    msg_index-=1
                                else:
                                    zhen+=1
                                    msg_index+=1
                            #                 这样会把所有之前的泡泡重新爆炸一边= =
                            for i in range(zhen,len(msg.split("|")[2].split("."))-1):
                                self.bomb.append(Bomb(int(msg.split("|")[2].split(".")[i].split(",")[1]),
                                                      int(msg.split("|")[2].split(".")[i].split(",")[2]),
                                                      self.screen,
                                                      self.map_data,int(msg.split("|")[2].split(".")[i].split(",")[3]),
                                                      "paopao",
                                                      int(msg.split("|")[2].split(".")[i].split(",")[0])))
            except:
                pass
    def clear(self):
        self.wall_list=[]
        self.daoju_list=[]# 道具
        self.robot_list=[]# 机器人
        self.robot_bomb=[]# 机器人炸弹
        self.box_list=[]# 箱子
        self.bomb=[]#玩家炸弹
        self.play_imformation_list=[]
        self.player_play_list=[]
    def load_data(self):
        game_folder = path.dirname(__file__)
        img_folder = path.join(game_folder,'image')
        self.background_img = pg.image.load("image/background1.png").convert_alpha()
        self.map_data = []
        with open(path.join(game_folder, 'map/map.txt'), 'rt') as f:
            for line in f:
                self.map_data.append(line[:-1])
    def new(self):
        xuhao=0
        for row, tiles in enumerate(self.map_data):
            for col, tile in enumerate(tiles):
                if tile == '1':
                    self.wall_list.append(Wall(self.screen, col, row,"wall"))
                elif tile == "a":
                    self.box_list.append(Box(self.screen, col, row,xuhao,"box"))
                    xuhao+=1
    def main_jiemian(self):
        #self.music=pg.mixer.music.load("image/1.mp3")
        #pg.mixer.music.play(-1)
        self.screen = pg.display.set_mode((800, 600))
        self.jiemian=0
        self.zhen=280
        while True:
                if self.zhen>=0:
                    self.zhen-=0.5
                    self.black.set_alpha(self.zhen)
                    self.screen.blit(self.mian_jiemian, (0, 0))
                    self.screen.blit(self.black,(0,0))
                else:
                    self.screen.blit(self.mian_jiemian, (0, 0))
                    self.screen.blit(self.black,(0,0))
                    mousex, mousey = pg.mouse.get_pos()
                    for event in pg.event.get():
                        # check for closing the window
                        if event.type == pg.QUIT:
                            quit()
                        if event.type == pg.MOUSEBUTTONDOWN:
                            # 74 366 342 444
                            # 74 750 342 552
                            if 74 <= mousex <= 342 and 366 <= mousey <= 444:
                                self.jiemian = 1
                                break
                            elif 74 <= mousex <= 342 and 474 <= mousey <= 553:
                                self.jiemian = 2
                                break
                    if self.jiemian!=0:break
                pg.display.update()
    def game_room(self):
        pg.display.set_caption(self.name)
        self.screen = pg.display.set_mode((1202, 900))
        self.jiemian=-1
        if self.thread == None:
            self.thread=xianchen.Thread(target=self.connect, args=())
            # 设置成守护线程
            self.thread.setDaemon(True)
            self.thread.start()
        self.clear()
        ready="no ready"
        self.zhen=280
        while True:
            if self.zhen >= 0:
                self.zhen -= 3
                self.black.set_alpha(self.zhen)
                self.screen.blit(self.room, (0, 0))
                if len(self.player_msg_list)>0:
                    for i in self.player_msg_list:
                        i.update()
                self.screen.blit(self.black, (0, 0))
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
            else:
                self.screen.blit(self.room, (0, 0))
                if not self.change_xinxi:
                    if len(self.player_msg_list)>0:
                        for i in self.player_msg_list:
                            i.update()
                mousex, mousey = pg.mouse.get_pos()
                for event in pg.event.get():
                    # check for closing the window
                    if event.type == pg.QUIT:
                        quit()
                    if event.type == pg.MOUSEBUTTONDOWN:
                        if 773 <= mousex <= 1057 and 467 <= mousey <= 824:
                            if ready=="ready":
                                ready="no ready"
                            else:
                                ready="ready"
                            self.client.sendall((("1|msg|2"+","+self.name+","+ready)+".").encode("utf8"))
                if self.jiemian != -1: break
            self.clock.tick(FPS)
            pg.display.update()
    def create_room(self):
        self.screen = pg.display.set_mode((800, 600))
        xuanze=0
        self.jiemian=-1
        while True:
            self.screen.blit(self.mian_jiemian, (0, 0))
            if xuanze==0:
                self.screen.blit(self.chuangjian_fj1,(130,63))
            else:
                self.screen.blit(self.chuangjian_fj2,(131,63))
            mousex, mousey = pg.mouse.get_pos()
            for event in pg.event.get():
                # check for closing the window
                if event.type == pg.QUIT:
                    quit()
                if event.type == pg.MOUSEBUTTONDOWN:
                    # 130  63   762 478
                    if 165 <= mousex <=288 and 135 <= mousey <=304:
                        xuanze=1
                    elif xuanze==1 and 320 <= mousex <=427 and 424 <= mousey <=461:
                        self.jiemian=3
                        break
                    elif 433 <= mousex <=538 and 424 <= mousey <=461:
                        self.jiemian=0
                        break
                    # 130  63   762 478
            if self.jiemian!=-1:break
            pg.display.update()
    def duoren(self):
        "准备是 44+159x  height 27"
        '''
        self.music = pg.mixer.music.load("image/2.mp3")
        pg.mixer.music.play(-1)
        '''
        self.load_data()
        self.screen = pg.display.set_mode((1280, 768))
        self.chat_box=chat_box(self.screen,self,self.client,"client")
        self.new()
        self.shu_ying=False
        self.end_kuang=None
        self.end_time = 350
        self.zhen = 280
        while True:
            if not self.shu_ying:
                if self.zhen >= 0:
                    self.zhen -= 3
                    self.black.set_alpha(self.zhen)
                    self.draw()
                    self.update()
                    self.screen.blit(self.black, (0, 0))
                    for event in pg.event.get():
                        if event.type == pg.QUIT:
                            quit()
                else:
                    self.events()
                    self.update()
                    self.draw()
            else:
                self.draw()
                self.update()
                self.end_kuang.update()#结束框
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
                if self.end_time>=0:
                    self.end_time-=1
                else:
                    if self.zhen>=280:
                        self.jiemian=3
                        self.player_index=0
                        break
                    self.zhen+=2.5
                    self.black.set_alpha(self.zhen)
                    self.screen.blit(self.black, (0, 0))
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
            self.clock.tick(FPS)
            pg.display.update()
    def danren(self):
        for i in range(0,10):
            self.robot_list.append(Robot(self.screen,self.map_data,1))

        #self.music=pg.mixer.music.load("image/2.mp3")
        #pg.mixer.music.play(-1)
        self.screen = pg.display.set_mode((1024, 768))
        while True:
            self.dt = self.clock.tick(FPS)
            self.events()
            self.update()
            self.draw()
            pg.display.update()
    def run(self):
        #界面运行
        # Game loop
        while True:
            if self.jiemian==0:
                self.main_jiemian()
            elif self.jiemian==1:
                self.danren()
            elif self.jiemian==2:
                self.create_room()
            elif self.jiemian==3:
                self.game_room()
            elif self.jiemian==4:
                self.duoren()
    def update(self):
        pass
    def events(self):
        for event in pg.event.get():
        # check for closing the window
            if event.type == pg.QUIT:
                quit()
            if event.type == pg.KEYDOWN:
                move=False
                self.chat_box.event(event.key)
                print(event.key)
                if not self.chat_box.useing:
                    if self.player_play_list[self.player_index].die == 0:
                        if event.key==pg.K_SPACE:
                            shifang=False
                            if len(self.bomb)>0:
                                for i in self.bomb:
                                    if i.x==self.player_play_list[self.player_index].x and i.y==self.player_play_list[self.player_index].y:
                                        shifang=True
                            # 房主放置水泡发送给所有连接池的玩家       索引                             x                                      y                                fanwei
                            if not shifang:
                                self.client.sendall(("2|bomb|"+str(self.player_play_list[self.player_index].x)+","+str(self.player_play_list[self.player_index].y)+","+str(self.player_play_list[self.player_index].fanwei)).encode("utf8"))
                            # self.client.sendall(("2|move|" + str(self.player_index) + "," + str(self.player_play_list[self.player_index].x) + "," + str(self.player_play_list[self.player_index].y) + ".").encode("utf8"))
                        elif event.key == pg.K_LEFT:
                            if len(self.bomb)>0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[self.player_index].x-1 and i.y == self.player_play_list[self.player_index].y:
                                        move=True
                            if not move and self.map_data[self.player_play_list[self.player_index].y][self.player_play_list[self.player_index].x-1]=="." or self.map_data[self.player_play_list[self.player_index].y][self.player_play_list[self.player_index].x-1]=="3":
                                self.client.sendall(("2|move|" + str(self.player_index) + "," + str(self.player_play_list[self.player_index].x-1) + "," + str(self.player_play_list[self.player_index].y) + ".").encode("utf8"))
                        elif event.key == pg.K_RIGHT:
                            if len(self.bomb) > 0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[self.player_index].x + 1 and i.y == self.player_play_list[self.player_index].y:
                                        move = True
                            if not move and self.map_data[self.player_play_list[self.player_index].y][self.player_play_list[self.player_index].x+1]=="." or self.map_data[self.player_play_list[self.player_index].y][self.player_play_list[self.player_index].x+1]=="3":
                                self.client.sendall(("2|move|" + str(self.player_index) + "," + str(self.player_play_list[self.player_index].x+1) + "," + str(self.player_play_list[self.player_index].y) + ".").encode("utf8"))
                        elif event.key == pg.K_UP:
                            if len(self.bomb) > 0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[self.player_index].x and i.y == self.player_play_list[self.player_index].y-1:
                                        move = True
                            if not move and self.map_data[self.player_play_list[self.player_index].y-1][self.player_play_list[self.player_index].x]=="." or self.map_data[self.player_play_list[self.player_index].y-1][self.player_play_list[self.player_index].x]=="3":
                                self.client.sendall(("2|move|" + str(self.player_index) + "," + str(self.player_play_list[self.player_index].x) + "," + str(self.player_play_list[self.player_index].y-1) + ".").encode("utf8"))
                        elif event.key == pg.K_DOWN:
                            if len(self.bomb) >0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[self.player_index].x and i.y == self.player_play_list[self.player_index].y+1:
                                        move = True
                            if not move and self.map_data[self.player_play_list[self.player_index].y+1][self.player_play_list[self.player_index].x]=="." or self.map_data[self.player_play_list[self.player_index].y+1][self.player_play_list[self.player_index].x]=="3":
                                self.client.sendall(("2|move|" + str(self.player_index) + "," + str(self.player_play_list[self.player_index].x) + "," + str(self.player_play_list[self.player_index].y+1) + ".").encode("utf8"))
                # 客户端返送的时候是  索引值,x,y,1.(索引值和x和y还有角色拥有的泡泡范围)
                #self.client.sendall(("2|move|"+str(self.player_index)+","+str(self.player_play_list[self.player_index].x)+","+str(self.player_play_list[self.player_index].y)+".").encode("utf8"))
    def draw_grid(self):
        for x in range(0,WIDTH,TILESIZE):
            pg.draw.line(self.screen, LIGHTGREY,(x,0),(x,HEIGHT))
        for y in range(0,HEIGHT,TILESIZE):
            pg.draw.line(self.screen, LIGHTGREY,(0,y),(WIDTH,y))

    def draw(self):
        # Game loop - draw
        # Draw / render
        # self.screen.fill(DARKGREY)
        self.screen.blit(self.background_img, [0, 0])
        for i in self.wall_list:
            i.update()
        self.screen.blit(self.play_imformation_kuang,(1024,0))
        for i in self.play_imformation_list:
            if i!=None:
                i.update()
        """
        if len(self.box_list)>0:#箱子
            for shu,i in enumerate(self.box_list):
                if self.map_data[i.y][i.x]=="4":
                    a = i.suiji()
                    eat=False
                    #遍历所有玩家,玩家吃到道具就break不然到最后一个玩家讲该道具放入道具list
                    for player in self.player_play_list:
                        if player.x == i.x and player.y == i.y:
                            if a == 1:
                                player.fanwei += 1
                            elif a == 2:
                                player.shuliang += 1
                            eat=True
                            break
                        if (a == 1 or a == 2) and eat :
                            self.jishu+=1
                            self.daoju_sjb+=str(i.x) + "," + str(i.y) + "," + str(a)+"*"
                            self.client.sendall(self.daoju_sjb.encode("utf8"))
                            self.daoju_list.append(Daoju(self.screen, i.x, i.y, a))
                        self.box_list.remove(i)
                        self.box_sjb ="7|"
                        for i in self.box_list:
                            self.box_sjb+=str(i.x)+","+str(i.y)+"*"
                        self.client.sendall(self.box_sjb.encode("utf8"))
                else:
                    i.update()
        if len(self.bomb) > 0:#玩家炸弹
            for i in self.bomb:
                if i.time == 70:
                    #self.map_data[i.y] = self.map_data[i.y][:i.x] + "." + self.map_data[i.y][i.x + 1:]
                    self.bomb_shuliang-=1
                if i.time == 0:
                    for x, y in i.list():
                        self.map_data[y] = self.map_data[y][:x] + "." + self.map_data[y][x + 1:]
                else:
                    if i.time == 70:# 时间
                        for x,y in i.list():
                            self.map_data[y]= self.map_data[y][:x] + "4" + self.map_data[y][x + 1:]
                        if self.map_data[self.player_play.y][self.player_play.x] == "4":
                            self.player_play.hurt()
        """
        if len(self.daoju_list)>0:
            for i in self.daoju_list:
                i.update()
        if len(self.box_list)>0:
            for index,i in enumerate(self.box_list):
                if i!="No":
                    i.update()
        if len(self.bomb) > 0:#玩家炸弹
            for i in self.bomb:
                i.update()
                if i.time == 0:
                    for x, y in i.list():
                        self.map_data[y] = self.map_data[y][:x] + "." + self.map_data[y][x + 1:]
        for i in self.player_play_list:
            if i!=None:
                i.update()
        # * after drawing everything , flip the display
        """
        if len(self.daoju_list)>0:
            for a in self.daoju_list:
                a.update()
        if len(self.robot_list)>0:
            for i in self.robot_list:
                i.update(self.map_data)
                self.msg += str(i.x) +","+ str(i.y) + "."
                if i.fangzhi_zhadan():
                    self.robot_bomb_sjb+=str(i.x)+","+str(i.y)+","+str(i.fanwei)+"*"
                    self.client.sendall(self.robot_bomb_sjb.encode("utf8"))
                    self.robot_bomb.append(Bomb(i.x,i.y,self.screen,self.map_data,i.fanwei,"guaishou"))
                    self.map_data[i.y] = self.map_data[i.y][:i.x] + "3" + self.map_data[i.y][i.x + 1:]
        """
        self.chat_box.update()
    def wait_room(self):
        #房间................
        pass
    def show_start_screen(self):
        # Game start screen
        pass
    def show_go_screen(self):
        # Game over screen
        pass


g = Game()
g.show_start_screen()
while g.running:
    g.run()
    g.show_go_screen()

pg.quit()





import pygame as pg
import unittest
import sys
import time
import random
import os
sys.path.append(os.path.join(os.path.dirname(__file__), '..', 'source'))
from object import Player, Robot, Bomb, Daoju, Wall, Box


# Here is white box test , we know input and output
# Test all of game objects etc. Player bomb and so on
class Test_Player(unittest.TestCase):


    @classmethod
    def setUpClass(cls) -> None:

        print('Ready to test Player class.')

    @classmethod
    def tearDownClass(cls) -> None:
        print('End of Player class test.')

    def test_init_position(self):
        print('Test player init position.')
        pos_x = 9
        pos_y = 8
        init_pos_x=9
        init_pos_y=8

        self.assertEqual((pos_x, pos_y), (init_pos_x, init_pos_y))

    def test_move(self):
        print('Test player movement.')
        # test player move with positive move
        player_x=545
        player_y=232
        new_x=player_x+5
        new_y=player_y+8
        self.assertEqual(new_x, 550)
        self.assertEqual(new_y, 240)

        # test player move with negative move

        player_x=545
        player_y=232
        new_x=player_x-5
        new_y=player_y-2
        self.assertEqual(new_x, 540)
        self.assertEqual(new_y, 230)

    def test_hurt(self):
        print('Test player hurt.')
        player_hp=1
        getAttack_hp=player_hp-1
        self.assertEqual(getAttack_hp, 0)


class Test_Wall(unittest.TestCase):
    def setUp(self) -> None:
        # Generate a random walls
        self.wall_pos = tuple(random.sample(range(5, 15), 2))

    @classmethod
    def tearDownClass(cls):
        print('End of Wall class test.')

    @classmethod
    def setUpClass(cls):

        cls.TITLESIZE = 32
        print('Ready to test Wall class.')



    def test_rect(self):
        print("Test wall's rect position.")
        rect=32
        wall_pos_x=8*rect
        wall_pos_y=9*rect
        self.assertEqual(wall_pos_x,256)
        self.assertEqual(wall_pos_y,288)




class Test_Box(unittest.TestCase):
    def setUp(self) -> None:
        self.x, self.y = tuple(random.sample(range(5, 15), 2))


    @classmethod
    def tearDownClass(cls):
        print('End of Box class test.')

    @classmethod
    def setUpClass(cls):

        print('Ready to test Box class.')

    def test_box_position(self):
        print('Test box position.')
        box_x=7
        box_y=8
        right_pos = (7, 8)
        self.assertEqual((box_x, box_y), right_pos)

    def test_box_image(self):
        print('Test box image.')


    def test_box_update(self):
        print('Test box update.')
        old_screen = (800,600)
        # Test whether the object has changed
        new_screen = (800,600)
        self.assertEqual(new_screen, old_screen)


class Test_Robot(unittest.TestCase):


    @classmethod
    def tearDownClass(cls):
        print('End of Robot class test.')

    @classmethod
    def setUpClass(cls):

        print('Ready to test Robot class.')

    def test_Bot_hp(self):
        print('Test bot hp update')

        # test player loc in px sample: x=5 y=10 in px is 160px and 320px
        self.shanshuo_zhen = 1
        self.hp = 20
        Robot.hurt(self)
        self.assertEqual(self.hp,19)

        self.hp = 39
        Robot.hurt(self)
        self.assertEqual(self.hp,38)

        self.hp = 27
        Robot.hurt(self)
        self.assertEqual(self.hp,26)


    def test_time(self):
        print('Test robot time.')
        robot_time = 100
        robot_time1 = 8
        self.assertEqual(robot_time, 100)
        self.assertEqual(robot_time1, 8)


if __name__ == '__main__':
    unittest.main()


# define colors
WHITE = (255,255,255)
BLACK = (0,0,0)
RED = (255,0,0)
GREEN = (0,255,0)
BLUE = (0,0,255)
DARKGREY = (40,40,40)
LIGHTGREY = (100,100,100)
YELLOW = (255,255,0)

10
# game setting
TITLE = "BomberKillers"

WIDTH = 1024 # 16 * 64  or 32 * 32
HEIGHT = 768 # 16 * 48 or 32 * 24 or 64 * 12
FPS = 60
BGCOLOR= DARKGREY



TILESIZE = 33
GRIDWIDTH =  WIDTH / TILESIZE
GRIDHEIGHT = HEIGHT / TILESIZE

# image
WALL_IMAGE = 'wall.png'
BACKGROUND_IMAGE = 'background.png'
BOX_IMAGE = 'box.png'
PLAYER_IMAGE = 'player.png'



import pygame as pg
import random
import sys
from os import path
from settings import *
from object import *
import time
import socket
import threading as xianchen
class Game:
    def __init__(self):
        # initalize game window, etc...
        pg.init()
        pg.mixer.init()
        #self.music=pg.mixer.music.load("image/1.mp3")
        #self.music=pg.mixer.music.load("image/2.mp3")
        self.screen = pg.display.set_mode((800,600))
        pg.display.set_caption(TITLE)
        self.clock = pg.time.Clock()
        # Let the key press down
        pg.key.set_repeat(500, 100)
        #main界面
        self.mian_jiemian=pg.image.load("image/mainground.png")
        self.chuangjian_fj1=pg.image.load("BNB/xz1.png")
        self.chuangjian_fj2=pg.image.load("BNB/xz2.png")
        self.room=pg.image.load("BNB/room.png")
        self.black=pg.image.load("BNB/black.png")
        #
        #创建房间初始化(你是房主)
        self.thread=None#服务器线程!!!!!!!!!!!!!
        self.sever=None
        self.client=None
        self.msg=""
        self.lianjie=False
        self.box_msg=""
        self.playing=False
        self.player_index=None# 判断哪个是你操控的对象
        #聊天框+指令系统
        self.chat_box=None
        #房间玩家内容
        self.player_msg_list=[]
        #游戏人物信息框
        self.play_imformation_list=[]
        #开始游戏()这是游戏的玩家内容
        self.player_play_list=[]
        #重要的数据包
        # 1是移动 2是放置炸弹 3是人机位置 4是怪物炸弹 5是刷新道具 6是拾取道具 7是墙的摧毁
        #用这种方式可以取消使用人物拾取道具的动作
        #
        self.zhen=255
        #数据直接给sever就行了
        self.play_imformation_kuang=pg.image.load("image/play_imformation/play information box.png")
        self.wall_list=[]
        self.daoju_list=[]# 道具
        self.robot_list=[]# 机器人
        self.robot_bomb=[]# 机器人炸弹
        self.box_list=[]# 箱子

        self.running = True
        self.bomb=[]#玩家炸弹
        self.cunfang=""
        self.bomb_shuliang=0
        self.jiemian=0
        #玩家皮肤信息（游戏的）
        self.player_play_list.append(Player(1,1,self.screen,1))
        self.name=""
        self.x=0
        self.jishu=0
        self.choice_name()
        #房间的
        self.player_msg_list.append(player_icons(self.screen, self.player_play_list[0].pifu,self.name,0,"fang zhu"))
        #32x24
        #pg.mixer.music.play(-1)
        """
        if pygame.mixer.music.get_busy() == False: #检查是否正在播放音乐
            pygame.mixer.music.play() #开始播放音乐流
        """
    def clear(self):
        self.wall_list=[]
        self.daoju_list=[]# 道具
        self.robot_list=[]# 机器人
        self.robot_bomb=[]# 机器人炸弹
        self.box_list=[]# 箱子
        self.bomb=[]#玩家炸弹
        self.play_imformation_list=[]
        self.player_play_list=[]
    def choice_name(self):
        self.name=random.choice(["Clever ","Naughty ","Handsome "," violent ","rich ","low-key ","steady ","Jovial"])+random.choice(["Duck","pig","froggy","John Doe","Passerby B","Bystander C","Xiao Ming","Xiao Hong","Xiao Zhang","Xiao Pao"])
    def receive(self):
            self.server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            self.server.bind((socket.gethostbyname(socket.gethostname()), 2001))
            self.server.listen(5)
            self.client, ip = self.server.accept()
            self.lianjie=True
            print("ok")
            while True:
                try:
                    """
                        self.bomb_sjb="2|"#炸弹[数据包]
                        self.daoju_sjb = "5|"  # 道具[数据包]
                        self.robot_sjb = "3|"  # 机器人[数据包]
                        self.robot_bomb_sjb = "4|"  # 机器人炸弹[数据包]
                        self.box_sjb = "7|"  # 箱子[数据包]
                    """
                    msg = self.client.recv(1024).decode("utf-8")
                    if msg.split("|")[0] == "1":
                        print(msg)
                        self.player_play1.x = int(msg.split("|")[1].split(",")[0])
                        self.player_play1.y = int(msg.split("|")[1].split(",")[1])
                    elif msg.split("|")[0] == "2":
                        #-1的话是因为后面会有多出一个*
                        #如果炸弹的x,y对不上该坐标将炸弹reomove掉,因为新加的炸弹在后面添加所以不会影响之前的炸弹的序号
                        if len(msg.split("|")[1].split("*"))-1!=self.robot_bomb:
                            self.map_data[int(msg.split("|")[1].split(",")[1])] = self.map_data[int(msg.split("|")[1].split(",")[1])][:int(msg.split("|")[1].split(",")[0])] + "3" + self.map_data[int(msg.split("|")[1].split(",")[1])][int(msg.split("|")[1].split(",")[0]) + 1:]
                            self.bomb.append(Bomb(int(msg.split("|")[1].split(",")[0]), int(msg.split("|")[1].split(",")[1]), self.screen, self.map_data, int(msg.split("|")[1].split(",")[2]), "123"))
                    elif msg.split("|")[0]== "3":
                        for i in range(0,len(msg.split("|")[1].split("."))):
                            self.robot_list[i].x=int(msg.split("|")[1].split(".")[i].split(",")[0])
                            self.robot_list[i].y=int(msg.split("|")[1].split(".")[i].split(",")[1])
                    elif msg.split("|")[0]=="4":
                        self.map_data[int(msg.split("|")[1].split(",")[1])] = self.map_data[int(msg.split("|")[1].split(",")[1])][:int(msg.split("|")[1].split(",")[0])] + "3" + self.map_data[int(msg.split("|")[1].split(",")[1])][int(msg.split("|")[1].split(",")[0]) + 1:]
                        self.robot_bomb.append(Bomb(int(msg.split("|")[1].split(",")[0]), int(msg.split("|")[1].split(",")[1]), self.screen, self.map_data, int(msg.split("|")[1].split(",")[2]), "guaishou"))
                        print("ok")
                    elif msg.split("|")[0]=="5":
                        self.daoju_list.append(Daoju(self.screen,int(msg.split("|")[1].split(",")[0]),int(msg.split("|")[1].split(",")[1]),int(msg.split("|")[1].split(",")[2])))
                    elif msg.split("|")[0]=="6":
                        del self.daoju_list[int(msg.split("|")[1])]
                    #1是移动 2是放置炸弹 3是人机位置 4是怪物炸弹 5是刷新道具 6是拾取道具 7是墙的摧毁
                    elif msg.split("|")[0]=="7":
                        del self.box_list[int(msg.split("|")[1])]
                except:
                    pass
    def connect(self):
        pass
    def load_data(self):
        game_folder = path.dirname(__file__)
        img_folder = path.join(game_folder,'image')
        self.background1 = pg.image.load("image/background1.png").convert_alpha()
        self.background2 = pg.image.load("image/background2.png").convert_alpha()
        self.map_data = []
        with open('map/map.txt', 'rt') as f:
            for line in f:
                self.map_data.append(line[:-1])
    def new(self):
        #    y    x
        for row, tiles in enumerate(self.map_data):
            for col, tile in enumerate(tiles):
                if tile == '1':
                    self.wall_list.append(Wall(self.screen,col,row,"wall"))
                # 其他的用不到的我不用继承了,1麻烦2写不出太突出的东西
                elif tile == "a":
                    self.box_list.append(Box(self.screen,col,row,self.sever.duixiang_index[1],"box"))
                    self.sever.box_msg+=str(self.sever.duixiang_index[1])+"."
                    self.sever.duixiang_index[1]+=1
    def single_new(self):
        for row, tiles in enumerate(self.map_data):
            for col, tile in enumerate(tiles):
                if tile == '2':
                    self.wall_list.append(Wall(self.screen,col,row,"stone"))
                # 其他的用不到的我不用继承了,1麻烦2写不出太突出的东西
                elif tile == "b":
                    self.box_list.append(Box(self.screen,col,row,1,"orange_box"))
                elif tile=="c":
                    self.box_list.append(Box(self.screen,col,row,1,"red_box"))
    def main_jiemian(self):
        #self.music=pg.mixer.music.load("image/1.mp3")
        #pg.mixer.music.play(-1)
        self.screen = pg.display.set_mode((800, 600))
        self.jiemian=0
        while True:
                if self.zhen>=0:
                    self.zhen-=0.5
                    self.black.set_alpha(self.zhen)
                    self.screen.blit(self.mian_jiemian, (0, 0))
                    self.screen.blit(self.black,(0,0))
                else:
                    self.screen.blit(self.mian_jiemian, (0, 0))
                    self.screen.blit(self.black,(0,0))
                    mousex, mousey = pg.mouse.get_pos()
                    for event in pg.event.get():
                        # check for closing the window
                        if event.type == pg.QUIT:
                            quit()
                        if event.type == pg.MOUSEBUTTONDOWN:
                            # 74 366 342 444
                            # 74 750 342 552
                            if 74 <= mousex <= 342 and 366 <= mousey <= 444:
                                self.jiemian = 1
                                break
                            elif 74 <= mousex <= 342 and 474 <= mousey <= 553:
                                self.jiemian = 2
                                break
                    if self.jiemian!=0:break
                pg.display.update()
    def game_room(self):
        self.screen = pg.display.set_mode((1202, 900))
        self.jiemian=-1
        if self.thread == None:
            self.thread=xianchen.Thread(target=Sever, args=(socket.gethostbyname(socket.gethostname()),self,))
            self.thread.setDaemon(True)
            self.thread.start()
        self.index=0
        self.zhen=280
        # 设置成守护线程
        while True:
            if self.zhen >= 0:
                self.zhen -= 3
                self.black.set_alpha(self.zhen)
                self.screen.blit(self.room, (0, 0))
                if len(self.player_msg_list)>0:
                    for i in self.player_msg_list:
                        i.update()
                self.screen.blit(self.black, (0, 0))
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
            else:
                self.screen.blit(self.room, (0, 0))
                mousex, mousey = pg.mouse.get_pos()
                if len(self.player_msg_list)>0:
                    for i in self.player_msg_list:
                        i.update()
                for event in pg.event.get():
                    # check for closing the window
                    if event.type == pg.QUIT:
                        quit()
                    if event.type == pg.MOUSEBUTTONDOWN:
                        len_player=0
                        if 773<=mousex<=1057 and 467<=mousey<=824:
                            for i in range(0,len(self.sever.js_xinxi.split("|")[2].split(".")) - 1):
                                if str(self.sever.js_xinxi.split("|")[2].split(".")[i]).split(",")[2]=="ready":
                                    len_player+=1
                            if len(self.sever.g_conn_pool)==len_player:
                                xuhao = 0
                                self.sever.clear()
                                self.clear()
                                self.player_play_list.append(Player(1, 1, self.screen, 1))
                                for i in range(0,len(self.sever.js_xinxi.split("|")[2].split("."))-1):
                                    if self.sever.js_xinxi.split("|")[2].split(".")[i]!="-1,no name,no ready":
                                        if i!=0:
                                            self.player_play_list.append(Player(1,1,self.screen,int(self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[0])))
                                            #                        x y   皮肤值   初始泡泡范围    名字
                                        #初始数据
                                        self.sever.play_player_move+="1,1."
                                        self.sever.player_imformation_msg+=self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[0]+self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[1]+"."
                                        self.sever.play_player_msg+="1,1,"+self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[0]+","+"1,"+self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[1]+","+str(i)+"."
                                        self.sever.play_life_msg+="0."
                                        self.play_imformation_list.append(Play_imformation(self.screen,int(self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[0]),self.sever.js_xinxi.split("|")[2].split(".")[i].split(",")[1],i))
                                        xuhao += 1
                                    else:
                                        self.play_imformation_list.append(None)
                                self.sever.send_player("1|Enter game|")
                                self.sever.send_player(self.sever.play_player_msg)
                                msg="2|move|"
                                for i in range(0,len(self.player_play_list)):
                                    msg+="1,1."
                                self.sever.send_player(msg)
                                self.playing=True
                                self.jiemian=4
                if self.jiemian != -1: break
            self.clock.tick(FPS)
            pg.display.update()
    def create_room(self):
        self.screen = pg.display.set_mode((800, 600))
        xuanze=0
        self.jiemian=-1
        while True:
            self.screen.blit(self.mian_jiemian, (0, 0))
            if xuanze==0:
                self.screen.blit(self.chuangjian_fj1,(130,63))
            else:
                self.screen.blit(self.chuangjian_fj2,(131,63))
            mousex, mousey = pg.mouse.get_pos()
            for event in pg.event.get():
                # check for closing the window
                if event.type == pg.QUIT:
                    quit()
                if event.type == pg.MOUSEBUTTONDOWN:
                    # 130  63   762 478
                    if 165 <= mousex <=288 and 135 <= mousey <=304:
                        xuanze=1
                    elif xuanze==1 and 320 <= mousex <=427 and 424 <= mousey <=461:
                        self.jiemian=3
                        break
                    elif 433 <= mousex <=538 and 424 <= mousey <=461:
                        self.jiemian=0
                        break
                    # 130  63   762 478
            if self.jiemian!=-1:break
            pg.display.update()
    def duoren(self):
        "准备是 44+159x  height 27"
        '''
        self.music = pg.mixer.music.load("image/2.mp3")
        pg.mixer.music.play(-1)
        '''
        self.load_data()
        self.screen = pg.display.set_mode((1280, 768))
        self.chat_box=chat_box(self.screen,self,self.sever,"sever")
        self.new()
        self.shu_ying = False
        self.end_kuang = None
        self.end_time = 350
        self.zhen=280
        while True:
            if not self.shu_ying:
                if self.zhen >= 0:
                    self.zhen -= 3
                    self.black.set_alpha(self.zhen)
                    self.draw()
                    self.update()
                    self.screen.blit(self.black, (0, 0))
                    for event in pg.event.get():
                        if event.type == pg.QUIT:
                            quit()
                else:
                    self.events()
                    self.draw()
                    self.update()
            else:
                self.draw()
                self.update()
                self.end_kuang.update()#结束框
                if self.end_time>=0:
                    self.end_time-=1
                else:
                    if self.zhen>=280:
                        self.playing=False
                        self.jiemian=3
                        break
                    self.zhen+=2.5
                    self.black.set_alpha(self.zhen)
                    self.screen.blit(self.black, (0, 0))
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
            self.clock.tick(FPS)
            pg.display.update()
    def run(self):
        #界面运行
        # Game loop
        while True:
            if self.jiemian==0:
                self.main_jiemian()
            elif self.jiemian==1:
                self.danren()
            elif self.jiemian==2:
                self.create_room()
            elif self.jiemian==3:
                self.game_room()
            elif self.jiemian==4:
                self.duoren()
    def update(self):
        #在游戏里面没啥作用的
        for i in self.wall_list:
            i.update()
        self.screen.blit(self.play_imformation_kuang,(1024,0))
        for i in self.play_imformation_list:
            if i!=None:
                i.update()
        self.chat_box.update()
    def events(self):
        # Game loop - events
        for event in pg.event.get():
        # check for closing the window
            if event.type == pg.QUIT:
                quit()
            if event.type == pg.KEYDOWN:
                move=None
                self.chat_box.event(event.key)
                if not self.chat_box.useing:
                    if self.player_play_list[0].die == 0:
                        if event.key==pg.K_SPACE:
                            shifang=False
                            if len(self.bomb)>0:
                                for i in self.bomb:
                                    if i.x==self.player_play_list[0].x and i.y==self.player_play_list[0].y:
                                        shifang=True
                            # 房主放置水泡发送给所有连接池的玩家       索引                             x                                      y                                fanwei
                            if not shifang :
                                self.sever.bomb_msg+=str(self.sever.duixiang_index[0])+","+str(self.player_play_list[0].x)+","+str(self.player_play_list[0].y)+","+str(self.player_play_list[0].fanwei)+"."
                                self.sever.send_player(self.sever.bomb_msg)
                                self.bomb.append(Bomb(self.player_play_list[0].x,self.player_play_list[0].y,self.screen,self.map_data,self.player_play_list[0].fanwei,"paopao",self.sever.duixiang_index[0]))
                                self.sever.duixiang_index[0]+=1
                        if event.key == pg.K_LEFT:
                            if len(self.bomb)>0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[0].x-1 and i.y == self.player_play_list[0].y:
                                        move=True
                            if not move and self.map_data[self.player_play_list[0].y][self.player_play_list[0].x-1]=="." or self.map_data[self.player_play_list[0].y][self.player_play_list[0].x-1]=="3":
                                self.player_play_list[0].move (dx=-1)
                        elif event.key == pg.K_RIGHT:
                            if len(self.bomb) > 0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[0].x + 1 and i.y == self.player_play_list[0].y:
                                        move = True
                            if not move and self.map_data[self.player_play_list[0].y][self.player_play_list[0].x + 1] =="." or self.map_data[self.player_play_list[0].y][self.player_play_list[0].x + 1] =="3":
                                    self.player_play_list[0].move (dx=1)
                        elif event.key == pg.K_UP:
                            if len(self.bomb) > 0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[0].x  and i.y == self.player_play_list[0].y-1:
                                        move = True
                            if not move and self.map_data[self.player_play_list[0].y-1][self.player_play_list[0].x ] =="." or self.map_data[self.player_play_list[0].y-1][self.player_play_list[0].x ] =="3":
                                    self.player_play_list[0].move (dy=-1)
                        elif event.key == pg.K_DOWN:
                            if len(self.bomb) > 0:
                                for i in self.bomb:
                                    if i.x == self.player_play_list[0].x  and i.y == self.player_play_list[0].y+1:
                                        move = True
                            if not move and self.map_data[self.player_play_list[0].y+1][self.player_play_list[0].x ] =="." or self.map_data[self.player_play_list[0].y+1][self.player_play_list[0].x ] =="3":
                                    self.player_play_list[0].move (dy=1)
                    # 人物移动的格式为x,y,1.(x和y还有角色拥有的泡泡范围)
                    #print("self.sever.play_player_msg"+self.sever.play_player_msg)
                    if len(self.daoju_list)>0:
                        daoju_msg = "2|property|"
                        zhi = -1
                        for index, daoju in enumerate(self.daoju_list):
                            if self.player_play_list[0].x == daoju.x and self.player_play_list[0].y == daoju.y:
                                zhi = index
                            else:
                                daoju_msg += str(daoju.x) + "," + str(daoju.y) + ",1," + str(daoju.index) + "."
                        if zhi != -1:
                            del self.daoju_list[zhi]
                        if self.sever.daoju_msg!=daoju_msg:
                            self.sever.send_player(daoju_msg)
                            self.sever.daoju_msg=daoju_msg
                    msg="2|move|"+str(self.player_play_list[0].x)+","+str(self.player_play_list[0].y)+"."
                    for i in range(1,len(self.sever.play_player_move.split("|")[2].split("."))-1):
                        if self.sever.play_player_move.split("|")[2].split(".")[i]=="None":
                            msg+="None."
                        else:
                            msg+=self.sever.play_player_move.split("|")[2].split(".")[i].split(",")[0]+","+self.sever.play_player_move.split("|")[2].split(".")[i].split(",")[1]+"."
                    self.sever.play_player_move=msg
                    for i in self.sever.g_conn_pool:
                        i.sendall(self.sever.play_player_move.encode("utf8"))
    def draw_grid(self):
        pass

    def draw(self):
        # Game loop - draw
        # Draw / render
        #self.screen.fill(DARKGREY)
        self.screen.blit(self.background1,[0,0])
        box_baozha=False
        if len(self.box_list)>0:
            for index,i in enumerate(self.box_list):
                if i!=None:
                    i.update()
                    if i.die==2:
                        box_baozha=True
                        if Daoju.jiance(i.daoju):
                            self.daoju_list.append(Daoju(self.screen,i.x,i.y,i.daoju,self.sever.duixiang_index[2]))
                            self.sever.daoju_msg+=str(i.x)+","+str(i.y)+","+str(i.daoju)+","+str(self.sever.duixiang_index[2])+"."
                            self.sever.duixiang_index[2]+=1
                            self.sever.send_player(self.sever.daoju_msg)
                        self.box_list[index]=None
                        self.map_data[i.y] = self.map_data[i.y][:i.x] + "." + self.map_data[i.y][i.x + 1:]
            else:
                if box_baozha:
                    box_msg = "2|box|"
                    for i in self.box_list:
                        if i==None:
                            box_msg+="No."
                        else:
                            box_msg+=str(i.xuhao)+"."
                    self.sever.box_msg=box_msg
                    self.sever.send_player(self.sever.box_msg)
        if len(self.bomb) > 0:#玩家炸弹
            for index,i in enumerate(self.bomb):
                i.update()
                if i.time==60:
                    box_die_pd=False
                    box_die_msg ="2|box_xinxi|"
                    for x, y in i.baozha_list:
                        for box in self.box_list:
                            if box!=None:
                                if x==box.x and y==box.y:
                                    #激活box的动画动画结束在box里面删除
                                    box_die_pd=True
                                    box.die=1
                                    box_die_msg +=str(box.xuhao)+"."
                                    break
                    if box_die_pd:
                        self.sever.send_player(box_die_msg)
                    #删除箱子且箱子渲染动画
                    # 删除时间0的泡泡
                if i.time == 0:
                    bomb_msg="2|bomb|"
                    self.bomb.remove(i)
                    for i in self.bomb:
                        bomb_msg+=str(i.index)+","+str(i.x)+","+str(i.y)+","+str(i.fanwei)+"."
                    if self.sever.bomb_msg!=bomb_msg:
                        self.sever.bomb_msg=bomb_msg
                        self.sever.send_player(self.sever.bomb_msg)
        if len(self.daoju_list)>0:
            for i in self.daoju_list:
                i.update()
        life_msg = "2|life|"
        people_shu=0
        for index,i in enumerate(self.player_play_list):
            if i == None:
                life_msg+="None."
            else:
                if self.map_data[i.y][i.x]=="3" and i.die==0:
                    i.die = 1
                    life_msg += "1."
                    self.play_imformation_list[index].zhuang_tai=i.die
                else:
                    life_msg+=str(i.die)+"."
                    if i.die==0:
                        people_shu+=1
                i.update()
        else:
            if people_shu<=1 and self.shu_ying == False:
                win_xuhao=None
                for index,i in enumerate(self.play_imformation_list):
                    if i!=None:
                        if i.zhuang_tai==0:
                            win_xuhao=index
                self.shu_ying=True
                self.end_kuang = end_kuang(self.screen, self.play_imformation_list,win_xuhao,0)
                self.sever.send_player("2|end|" + str(win_xuhao))
            if life_msg != self.sever.play_life_msg:
                self.sever.play_life_msg = life_msg
                self.sever.send_player(self.sever.play_life_msg)
        self.draw_grid()
    def danren(self):
        #self.music=pg.mixer.music.load("image/2.mp3")
        #pg.mixer.music.play(-1)
        self.screen = pg.display.set_mode((561, 495))
        self.wall_list=[]
        self.box_list=[]
        self.daoju_list=[]
        self.guaishou_list=[]
        self.single_load_information()
        self.single_new()
        for i in range(0,6):
            self.guaishou_list.append(ghost(self.screen,self.map_data))
        self.zhen=280
        self.shu_ying=False
        self.end_time=300
        while True:
            if not self.shu_ying:
                if self.zhen >= 0:
                    self.zhen -= 3
                    self.black.set_alpha(self.zhen)
                    self.single_update()
                    self.single_draw()
                    self.screen.blit(self.black, (0, 0))
                    for event in pg.event.get():
                        if event.type == pg.QUIT:
                            quit()
                else:
                    self.single_events()
                    self.single_update()
                    self.single_draw()
            else:
                self.single_update()
                self.single_draw()
                if self.end_time>=0:
                    self.end_time-=1
                else:
                    if self.zhen>=280:
                        self.jiemian=0
                        break
                    self.zhen+=2.5
                    self.black.set_alpha(self.zhen)
                    self.screen.blit(self.black, (0, 0))
                for event in pg.event.get():
                    if event.type == pg.QUIT:
                        quit()
            self.clock.tick(FPS)
            pg.display.update()
    def single_load_information(self):
        self.map_data = []
        with open('map/single_map.txt', 'rt') as f:
            for line in f:
                self.map_data.append(line[:-1])
        self.player=Player(1,1,self.screen,1)
        self.background2 = pg.image.load("image/background2.png").convert_alpha()
    def single_events(self):
        for event in pg.event.get():
            # check for closing the window
            if event.type == pg.QUIT:
                quit()
            if event.type == pg.KEYDOWN:
                move = None
                if self.player.die == 0:
                    if event.key == pg.K_SPACE:
                        shifang = False
                        if len(self.bomb) > 0:
                            for i in self.bomb:
                                if i.x == self.player.x and i.y == self.player.y:
                                    shifang = True
                        if not shifang:
                            self.bomb.append(Bomb(self.player.x, self.player.y, self.screen,self.map_data, self.player.fanwei, "paopao",1))
                    if event.key == pg.K_LEFT:
                        if len(self.bomb) > 0:
                            for i in self.bomb:
                                if i.x == self.player.x - 1 and i.y == self.player.y:
                                    move = True
                        if not move and self.map_data[self.player.y][self.player.x - 1] == "." or self.map_data[self.player.y][self.player.x - 1] == "3":
                            self.player.move(dx=-1)
                    elif event.key == pg.K_RIGHT:
                        if len(self.bomb) > 0:
                            for i in self.bomb:
                                if i.x == self.player.x + 1 and i.y == self.player.y:
                                    move = True
                        if not move and self.map_data[self.player.y][self.player.x + 1] == "." or self.map_data[self.player.y][self.player.x + 1] == "3":
                            self.player.move(dx=1)
                    elif event.key == pg.K_UP:
                        if len(self.bomb) > 0:
                            for i in self.bomb:
                                if i.x == self.player.x and i.y == self.player.y - 1:
                                    move = True
                        if not move and self.map_data[self.player.y - 1][self.player.x] == "." or self.map_data[self.player.y - 1][self.player.x] == "3":
                            self.player.move(dy=-1)
                    elif event.key == pg.K_DOWN:
                        if len(self.bomb) > 0:
                            for i in self.bomb:
                                if i.x == self.player.x and i.y == self.player.y + 1:
                                    move = True
                        if not move and self.map_data[self.player.y + 1][self.player.x] == "." or self.map_data[self.player.y + 1][self.player.x] == "3":
                            self.player.move(dy=1)
                    if len(self.daoju_list)>0:
                        zhi = -1
                        for index, daoju in enumerate(self.daoju_list):
                            if self.player.x == daoju.x and self.player.y == daoju.y:
                                zhi = index
                        if zhi != -1:
                            del self.daoju_list[zhi]
    def single_update(self):
        self.screen.blit(self.background2,(0,0))
        if len(self.box_list)>0:
            for index,i in enumerate(self.box_list):
                if i!=None:
                    i.update()
                    if i.die==2:
                        if Daoju.jiance(i.daoju):
                            self.daoju_list.append(Daoju(self.screen,i.x,i.y,i.daoju,1))
                        self.box_list[index]=None
                        self.map_data[i.y] = self.map_data[i.y][:i.x] + "." + self.map_data[i.y][i.x + 1:]
        if len(self.bomb) > 0:#玩家炸弹
            for index,i in enumerate(self.bomb):
                i.update()
                if i.time==60:
                    for x, y in i.baozha_list:
                        for box in self.box_list:
                            if box != None:
                                if x == box.x and y == box.y:
                                    # 激活box的动画动画结束在box里面删除
                                    box.die = 1
                                    break
                    #删除箱子且箱子渲染动画
                    # 删除时间0的泡泡
                if i.time == 0:
                    self.bomb.remove(i)
        self.player.update()
        if len(self.daoju_list)>0:
            for i in self.daoju_list:
                i.update()
        if self.map_data[self.player.y][self.player.x]=="3" and self.player.die==0:
            self.shu_ying=True
            self.player.die=1
    def single_draw(self):
        if len(self.guaishou_list)>0:
            for i in self.guaishou_list:
                i.update()
                if self.player.y==i.y and self.player.x==i.x and self.player.die==0:
                    self.player.die=1
                    self.player.die_zhen=17
                    self.player.time=0
                    self.shu_ying = True
                if i.die==2:
                    self.guaishou_list.remove(i)
                    print("当前怪兽数量"+str(len(self.guaishou_list)))
        else:
            self.shu_ying=True
        for i in self.wall_list:
            i.update()
    def wait_room(self):
        #房间................
        pass
    def show_start_screen(self):
        # Game start screen
        pass
    def show_go_screen(self):
        # Game over screen
        pass
    def jiexi(self,str1):
        self.player_msg_list=[]
        for i in range(0, len(str1.split("|")[2].split(".")) - 1):
            if str1.split("|")[2].split(".")[i]!="-1,no name,no ready":
                self.player_msg_list.append(player_icons(self.screen, int(str1.split("|")[2].split(".")[i].split(",")[0]), str1.split("|")[2].split(".")[i].split(",")[1], i,str1.split("|")[2].split(".")[i].split(",")[2]))
    def bomb_jiexi(self,x,y,fanwei,index):
        print("ok")
        self.bomb.append(Bomb(int(x),int(y),self.screen,self.map_data,int(fanwei),"paopao",index))
        print("ok")
class Sever():
    def __init__(self,ADDRESS,duixiang):
        self.duixiang=duixiang
        self.duixiang.sever=self
        print(self.duixiang.sever)
        self.ADDRESS =(ADDRESS,5000)  # 绑定地址("x.xxx.xxx.xxx",5000)
        self.g_socket_server = None  # 负责监听的socket
        self.g_conn_pool = []  # 联机泡泡堂的连接池
        #
        self.js_xinxi="1|msg|"# 玩家角色信息(进入游戏将部分信息转换成游戏对象)
        self.js_xinxi+=str(self.duixiang.player_play_list[0].pifu)+","+self.duixiang.name+","+"no ready"+"."
        #             角色信息,名字,是否准备
        self.js_xinxi+= "-1,no name,no ready.-1,no name,no ready.-1,no name,no ready.-1,no name,no ready.-1,no name,no ready.-1,no name,no ready.-1,no name,no ready."
        self.play_msg_list=[]
        #
        #1是没有进游戏的时候,2是进游戏的时候

        self.play_player_msg="2|js|"# 玩家[数据包][存放]{前面是2|js| 后面是2|move|}
        self.player_imformation_msg="2|imformation|"#存放人物信息列表框
        self.play_player_move="2|move|"#玩家移动
        self.play_life_msg="2|life|"#玩家状态数据
        self.bomb_msg="2|bomb|"# 炸弹[数据包]
        self.daoju_msg = "2|property|"  # 道具[数据包]
        self.box_msg = "2|box|"  # 箱子[数据包]
        #                 bomb_index,box_index,property_index
        self.duixiang_index=[0,0,0]
        self.init()
        self.accept_client()
    def init(self):
        # 初始化服务端
        self.g_socket_server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.g_socket_server.bind(self.ADDRESS)
        self.g_socket_server.listen(5)
    def clear(self):
        self.play_player_msg="2|js|"# 玩家[数据包][存放]
        self.player_imformation_msg="2|imformation|"#存放人物信息列表框
        self.play_player_move="2|move|"#玩家移动
        self.play_life_msg="2|life|"#玩家状态数据
        self.bomb_msg="2|bomb|"# 炸弹[数据包]
        self.daoju_msg = "2|property|"  # 道具[数据包]
        self.box_msg = "2|box|"  # 箱子[数据包]
        #                 bomb_index,box_index,property_index
        self.duixiang_index=[0,0,0]
    def return_g_conn_pool(self):
        pass
    def send_player(self,msg):
        print("msg"+msg)
        if len(self.g_conn_pool)>0:
            for i in self.g_conn_pool:
                i.sendall(msg.encode("utf8"))
                time.sleep(0.005)
    def accept_client(self):
        # 接收新连接
        join=False
        while True:
            client,ip = self.g_socket_server.accept()  # 阻塞，等待客户端连接
            # 加入连接池
            print('链接+'+str(self.duixiang.playing))
            if len(self.g_conn_pool)<=7 and not self.duixiang.playing :
                self.g_conn_pool.append(client)
                msg=client.recv(2048).decode(encoding="utf-8")
                js_xinxi = "1|msg|"  # 玩家角色信息(进入游戏将部分信息转换成游戏对象)
                biaoji=False
                xuhao=-10
                for i in range(0,len(self.js_xinxi.split("|")[2].split("."))-1):
                    if self.js_xinxi.split("|")[2].split(".")[i]=="-1,no name,no ready" and not biaoji:
                        xuhao=i
                        js_xinxi+=str(msg).split("|")[2]
                        biaoji=True
                        #js+=self.js.split("|")[2].split(".")[i]+"."
                    else:
                        js_xinxi+=self.js_xinxi.split("|")[2].split(".")[i]+"."
                self.js_xinxi=js_xinxi
                self.duixiang.jiexi(self.js_xinxi)
                thread = xianchen.Thread(target=self.message_handle, args=(client,xuhao))
                # 设置成守护线程
                thread.setDaemon(True)
                thread.start()
                self.send_player(js_xinxi)
            else:
                print("No")
                client.sendall("NO|".encode("utf8"))

    def message_handle(self,client,wz):
        while True:
            try:
                bytes = client.recv(2048).decode("utf8")  # 接收客户端消息
                print(bytes)
                if str(bytes).split("|")[0]=="1":
                    js_xinxi = "1|msg|"
                    for i in range(0,len(self.js_xinxi.split("|")[2].split("."))-1):
                        if i!=wz:
                            js_xinxi+=self.js_xinxi.split("|")[2].split(".")[i]+"."
                        else:
                            js_xinxi+=str(bytes).split("|")[2]
                    self.js_xinxi=js_xinxi
                    self.duixiang.jiexi(self.js_xinxi)
                    self.send_player(self.js_xinxi)
                elif str(bytes).split("|")[0]=="2":
                    if str(bytes).split("|")[1]=="move":
                        self.duixiang.player_play_list[int(str(bytes).split("|")[2].split(".")[0].split(",")[0])].x=int(str(bytes).split("|")[2].split(".")[0].split(",")[1])
                        self.duixiang.player_play_list[int(str(bytes).split("|")[2].split(".")[0].split(",")[0])].y=int(str(bytes).split("|")[2].split(".")[0].split(",")[2])
                        daoju_msg="2|property|"
                        zhi=-1
                        for index,daoju in enumerate(self.duixiang.daoju_list):
                            if int(str(bytes).split("|")[2].split(".")[0].split(",")[1])==daoju.x and int(str(bytes).split("|")[2].split(".")[0].split(",")[2])==daoju.y:
                                zhi=index
                            else:
                                daoju_msg+=str(daoju.x) + "," + str(daoju.y) + ",1," + str(daoju.index) + "."
                        if zhi!=-1:del self.duixiang.daoju_list[zhi]
                        if daoju_msg!=self.daoju_msg:
                            self.send_player(daoju_msg)
                            self.daoju_msg=daoju_msg
                        #以下重构所有角色 位置 的数据包
                        js_xinxi = "2|move|"
                        for i in range(0,len(self.play_player_move.split("|")[2].split("."))-1):
                            if int(str(bytes).split("|")[2].split(",")[0])==i:
                                js_xinxi+=str(bytes).split("|")[2].split(".")[0].split(",")[1]+","+str(bytes).split("|")[2].split(".")[0].split(",")[2]+"."
                            else:
                                if self.play_player_move.split("|")[2].split(".")[i]=="None":
                                    js_xinxi+="None."
                                else:
                                    js_xinxi+=self.play_player_move.split("|")[2].split(".")[i]+"."
                        self.play_player_move=js_xinxi
                        self.send_player(self.play_player_move)
                        print("move："+self.play_player_move)
                    elif str(bytes).split("|")[1]=="bomb":
                        print("receive:"+bytes)
                        self.bomb_msg+=str(self.duixiang_index[0])+","+str(bytes).split("|")[2].split(",")[0]+","+str(bytes).split("|")[2].split(",")[1]+","+str(bytes).split("|")[2].split(",")[2]+"."
                        self.duixiang.bomb_jiexi(int(str(bytes).split("|")[2].split(",")[0]),int(str(bytes).split("|")[2].split(",")[1]),int(str(bytes).split("|")[2].split(",")[2]),self.duixiang_index[0])
                        #self.duixiang.bomb(Bomb(int(str(bytes).split("|")[2].split(",")[0]),int(str(bytes).split("|")[2].split(",")[1]),self.duixiang.screen,self.duixiang.map_data,str(bytes).split("|")[2].split(",")[2],"paopao",self.duixiang_index[0]))
                        self.duixiang_index[0]+=1
                        print("use")
                        self.send_player(self.bomb_msg)
                    elif str(bytes).split("|")[1]=="chat":
                        self.duixiang.chat_box.add_information(str(bytes).split("|")[2])
                        self.send_player(bytes)
            except :
                #无
                if not self.duixiang.playing:#在房间
                    js_xinxi = "1|msg|"
                    for i in range(0,len(self.js_xinxi.split("|")[2].split("."))-1):
                        if i!=wz:
                            js_xinxi+=self.js_xinxi.split("|")[2].split(".")[i]+"."
                        else:
                            js_xinxi+="-1,no name,no ready."
                    self.js_xinxi=js_xinxi
                    self.duixiang.jiexi(self.js_xinxi)
                    self.g_conn_pool.remove(client)
                    self.send_player(self.js_xinxi)
                else:#在游戏里面
                    print("掉线")
                    self.g_conn_pool.remove(client)
                    js_xinxi = "1|msg|"
                    for i in range(0,len(self.js_xinxi.split("|")[2].split("."))-1):
                        if i==wz:
                            js_xinxi+="-1,no name,no ready."
                        else:
                            js_xinxi+=self.js_xinxi.split("|")[2].split(".")[i]+"."
                    self.js_xinxi=js_xinxi
                    self.duixiang.jiexi(self.js_xinxi)
                    print("js_xinxi"+self.js_xinxi)
                    play_player_msg = "2|js|"  # 玩家[数据包][存放]{前面是2|js| 后面是2|move|}
                    player_imformation_msg = "2|imformation|"  # 存放人物信息列表框
                    play_player_move = "2|move|"  # 玩家移动
                    play_life_msg = "2|life|"  # 玩家状态数据
                    for i in range(0,len(self.play_player_msg.split("|")[2].split("."))-1):
                        if self.play_player_msg.split("|")[2].split(".")[i]=="None" :
                            play_player_msg += "None."
                            player_imformation_msg += "None."
                            play_player_move += "None."
                            play_life_msg += "None."
                        else:
                            if int(self.play_player_msg.split("|")[2].split(".")[i].split(",")[5]) == wz:
                                self.duixiang.player_play_list[i] = None
                                self.duixiang.play_imformation_list[i] = None
                                play_player_msg += "None."
                                player_imformation_msg += "None."
                                play_player_move += "None."
                                play_life_msg += "None."
                            else:
                                play_player_msg += self.play_player_msg.split("|")[2].split(".")[i]+"."
                                player_imformation_msg += self.player_imformation_msg.split("|")[2].split(".")[i]+"."
                                play_player_move += self.play_player_move.split("|")[2].split(".")[i]+"."
                                play_life_msg += self.play_life_msg.split("|")[2].split(".")[i]+"."
                    self.play_player_msg=play_player_msg
                    self.play_player_move=play_player_move
                    self.player_imformation_msg=player_imformation_msg
                    self.play_life_msg=play_life_msg
                    if self.duixiang.shu_ying==False:
                        shu = 0
                        for i in range(0,len(self.play_life_msg.split("|")[2].split("."))-1):
                            if self.play_life_msg.split("|")[2].split(".")[i]!="None" and self.play_life_msg.split("|")[2].split(".")[i]!="1"  and self.play_life_msg.split("|")[2].split(".")[i]!="2":
                                shu+=1
                        if shu<=1:
                            self.duixiang.end_kuang=end_kuang(self.duixiang.screen,self.duixiang.play_imformation_list,0,0)
                            self.duixiang.shu_ying=True
                            self.send_player("2|end|")
                    self.send_player(play_player_msg)
                break

g = Game()
g.show_start_screen()
while g.running:
    g.run()
    g.show_go_screen()

pg.quit()




from setuptools import setup, find_packages

setup(
    name='BomberKillers',
    version='0.0.3',
    author="Sun Yilong,Tang Shaozhe,Li Zhipeng,Ramzan Muhammad",
    author_email='bcfogs@inf.elte.hu,qs4oz8@inf.elte.hu,g31r6t@inf.elte.hu,pn8uom@inf.elte.hu',
    packages=find_packages('source'),
    package_dir={'': 'source'},
	py_modules=["main","object","settings","yonghu","yonghu2"],
    url='https://github.com/Tang634724712/BomberKillers',
    keywords='python game',
    install_requires=[
          'pygame',
      ],

)
